@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Completion::GetoptLongComplete;
 
-our $DATE = '2015-08-26'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-04-30'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -24,6 +24,13 @@ sub weave_section {
         return;
     }
 
+    # file looks like a completer script, don't bother generating completer for
+    # completer :)
+    if ($command_name =~ /\A_/) {
+        $self->log_debug(["skipped script %s (a completer itself)", $filename]);
+        return;
+    }
+
     # find file content in zilla object, not directly in filesystem, because the
     # file might be generated dynamically by dzil.
     my $file = first { $_->name eq $filename } @{ $input->{zilla}->files };
@@ -63,7 +70,7 @@ Pod::Weaver::Section::Completion::GetoptLongComplete - Add a COMPLETION section
 
 =head1 VERSION
 
-This document describes version 0.07 of Pod::Weaver::Section::Completion::GetoptLongComplete (from Perl distribution Pod-Weaver-Section-Completion-GetoptLongComplete), released on 2015-08-26.
+This document describes version 0.08 of Pod::Weaver::Section::Completion::GetoptLongComplete (from Perl distribution Pod-Weaver-Section-Completion-GetoptLongComplete), released on 2016-04-30.
 
 =head1 SYNOPSIS
 
@@ -79,10 +86,6 @@ completion for the scripts.
 
 =for Pod::Coverage weave_section
 
-=head1 SEE ALSO
-
-L<Getopt::Long::Complete>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Section-Completion-GetoptLongComplete>.
@@ -99,13 +102,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Getopt::Long::Complete>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
